@@ -41,16 +41,16 @@ class IvyBloomAPIClient:
                 "Authentication required. Please run 'ivybloom auth login' (browser/device/link) or provide an API key."
             )
     
-    def _get_default_headers(self) -> Dict[str, str]:
+    def _get_default_headers(self, *, prefer_jwt: bool = False) -> Dict[str, str]:
         """Get default headers for requests"""
         # Build default headers including auth; prefer API key for stability, then JWT/OAuth
         headers = {
             "Content-Type": "application/json",
-            "User-Agent": "ivybloom-cli/0.4.37",
+            "User-Agent": "ivybloom-cli/0.5.15",
             "Accept": "application/json"
         }
         # Add Authorization header via AuthManager (JWT/OAuth/API key)
-        headers.update(self.auth_manager.get_auth_headers())
+        headers.update(self.auth_manager.get_auth_headers(prefer_jwt=prefer_jwt))
         
         # Include client identifier for analytics and linking
         try:
@@ -62,10 +62,10 @@ class IvyBloomAPIClient:
         
         return headers
     
-    def _refresh_headers(self):
+    def _refresh_headers(self, *, prefer_jwt: bool = False):
         """Refresh authentication headers (for retry logic)"""
         # Get fresh headers including updated Clerk session
-        fresh_headers = self._get_default_headers()
+        fresh_headers = self._get_default_headers(prefer_jwt=prefer_jwt)
         self.client.headers.update(fresh_headers)
     
     def _make_request(self, method: str, endpoint: str, **kwargs) -> httpx.Response:
@@ -111,7 +111,7 @@ class IvyBloomAPIClient:
             if detail == "CLI_CLIENT_UNLINKED":
                 raise Exception("❌ CLI not linked to your account. Run 'ivybloom auth link' to link this CLI installation.")
             
-            # Try refreshing tokens and retrying once
+            # Try refreshing API key/JWT headers and retrying once
             # Send human-readable notice to stderr so stdout remains machine-parseable
             print("Access token may be expired, attempting refresh...", file=sys.stderr)
             self._refresh_headers()
@@ -119,10 +119,15 @@ class IvyBloomAPIClient:
             # Retry the request with refreshed headers
             retry_response = self._make_request("GET", endpoint, params=params)
             if retry_response.status_code == 401:
-                raise Exception("❌ Authentication failed. Please run 'ivybloom auth login' or check your API key.")
-            
-            # Use the retry response for further processing
-            response = retry_response
+                # Secondary fallback: retry once forcing JWT if available
+                self._refresh_headers(prefer_jwt=True)
+                retry_jwt_response = self._make_request("GET", endpoint, params=params)
+                if retry_jwt_response.status_code == 401:
+                    raise Exception("❌ Authentication failed. Please run 'ivybloom auth login' or check your API key.")
+                response = retry_jwt_response
+            else:
+                # Use the retry response for further processing
+                response = retry_response
             
         elif response.status_code == 403:
             raise Exception("❌ Access denied. You don't have permission for this resource.")
@@ -162,18 +167,19 @@ class IvyBloomAPIClient:
             if detail == "CLI_CLIENT_UNLINKED":
                 raise Exception("Authentication required. Run 'ivybloom auth link' to link this CLI and retry.")
             
-            # Try refreshing tokens and retrying once
-            # Send human-readable notice to stderr so stdout remains machine-parseable
+            # Prefer forcing JWT/OAuth token first (some backends require verifiable user token)
             print("Access token may be expired, attempting refresh...", file=sys.stderr)
-            self._refresh_headers()
-            
-            # Retry the request with refreshed headers
-            retry_response = self._make_request("POST", endpoint, **kwargs)
-            if retry_response.status_code == 401:
-                raise Exception("Authentication failed. Please check your API key or login status.")
-            
-            # Use the retry response for further processing
-            response = retry_response
+            self._refresh_headers(prefer_jwt=True)
+            retry_jwt_first = self._make_request("POST", endpoint, **kwargs)
+            if retry_jwt_first.status_code == 401:
+                # Fallback: refresh default headers (API key) and retry
+                self._refresh_headers(prefer_jwt=False)
+                retry_default = self._make_request("POST", endpoint, **kwargs)
+                if retry_default.status_code == 401:
+                    raise Exception("Authentication failed. Please check your API key or login status.")
+                response = retry_default
+            else:
+                response = retry_jwt_first
             
         elif response.status_code == 403:
             raise Exception("Access denied. You don't have permission for this resource.")
@@ -202,7 +208,12 @@ class IvyBloomAPIClient:
                 detail = None
             if detail == "CLI_CLIENT_UNLINKED":
                 raise Exception("Authentication required. Run 'ivybloom auth link' to link this CLI and retry.")
-            raise Exception("Authentication failed. Please check your API key or login status.")
+            # Retry once forcing JWT/OAuth token if available
+            self._refresh_headers(prefer_jwt=True)
+            retry_jwt_response = self._make_request("DELETE", endpoint)
+            if retry_jwt_response.status_code == 401:
+                raise Exception("Authentication failed. Please check your API key or login status.")
+            response = retry_jwt_response
         elif response.status_code == 403:
             raise Exception("Access denied. You don't have permission for this resource.")
         elif response.status_code == 404:
@@ -300,9 +311,13 @@ class IvyBloomAPIClient:
         
         return self.post("/api/cli/jobs", json_data=payload)
     
-    def get_job_status(self, job_id: str, include_logs: bool = False) -> Dict[str, Any]:
+    def get_job_status(self, job_id: str, include_logs: bool = False, logs_tail: int | None = None) -> Dict[str, Any]:
         """Get job status"""
-        params = {"include_logs": include_logs} if include_logs else None
+        params: Dict[str, Any] | None = None
+        if include_logs:
+            params = {"include_logs": True}
+            if isinstance(logs_tail, int) and logs_tail > 0:
+                params["logs_tail"] = logs_tail
         response = self.get(f"/api/cli/jobs/{job_id}", params=params)
         
         # Map database field names to CLI-expected field names for backward compatibility
