@@ -27,33 +27,15 @@ console = get_console()
 
 @click.group()
 def jobs():
-    """📋 Computational job management and monitoring
-    
-    Monitor, manage, and retrieve results from your computational biology jobs.
-    
-    JOB LIFECYCLE:
-    
-      1. Submit:       ivybloom run <tool> [parameters...]
-      2. Monitor:      ivybloom jobs status <job_id> --follow  
-      3. List all:     ivybloom jobs list --status running
-      4. Get results:  ivybloom jobs results <job_id>
-      5. Download:     ivybloom jobs download <job_id>
-    
-    COMMON WORKFLOWS:
-    
-      📊 Monitor active jobs:     ivybloom jobs list --status running
-      🔍 Filter by tool:          ivybloom jobs list --tool esmfold  
-      📁 Filter by project:       ivybloom jobs list --project-id <id>
-      ⏱️  Recent jobs:            ivybloom jobs list --limit 10
-      ❌ Debug failed jobs:       ivybloom jobs list --status failed
-      📥 Download results:        ivybloom jobs download <job_id>
-    
-    JOB STATUSES:
-      🟡 pending → 🔵 running → 🟢 completed | 🔴 failed | ⚫ cancelled
-    
-    💡 TIP: Use 'ivybloom jobs status <job_id> --follow' to watch job progress live!
-    
-    Run 'ivybloom jobs <command> --help' for detailed help on each command.
+    """Manage and monitor computational jobs
+
+    Common:
+      - List:    ivybloom jobs list [--status running --tool esmfold]
+      - Status:  ivybloom jobs status <job_id> [--follow]
+      - Results: ivybloom jobs results <job_id>
+      - Download:ivybloom jobs download <job_id>
+
+    Tip: Use '--follow' to watch long-running jobs live.
     """
     pass
 
@@ -242,10 +224,12 @@ def list(ctx, project_id, status, tool, limit, offset, created_after, created_be
 @jobs.command()
 @click.argument('job_id')
 @click.option('--follow', '-f', is_flag=True, help='Follow job progress')
+@click.option('--interval', default=5, show_default=True, type=int, help='Polling interval in seconds for --follow')
 @click.option('--logs', is_flag=True, help='Include execution logs')
+@click.option('--logs-tail', type=int, default=50, show_default=True, help='When --logs is set, include only the last N log lines')
 @click.option('--format', default='table', type=click.Choice(['table', 'json']), help='Output format')
 @click.pass_context
-def status(ctx, job_id, follow, logs, format):
+def status(ctx, job_id, follow, interval, logs, logs_tail, format):
     """📊 Monitor job status and progress
     
     Check the current status, progress, and details of a specific job.
@@ -285,7 +269,7 @@ def status(ctx, job_id, follow, logs, format):
                 # Follow mode - continuously update status
                 with Live(console=console, refresh_per_second=2) as live:
                     while True:
-                        job_data = client.get_job_status(job_id, include_logs=logs)
+                        job_data = client.get_job_status(job_id, include_logs=logs, logs_tail=logs_tail if logs else None)
                         
                         # Create status display
                         status_panel = _create_status_panel(job_data)
@@ -296,10 +280,10 @@ def status(ctx, job_id, follow, logs, format):
                         if status in ['COMPLETED', 'SUCCESS', 'FAILURE', 'FAILED', 'CANCELLED', 'ARCHIVED']:
                             break
                         
-                        time.sleep(5)  # Wait 5 seconds before next update
+                        time.sleep(max(1, int(interval)))  # Adjustable polling interval
             else:
                 # Single status check
-                job_data = client.get_job_status(job_id, include_logs=logs)
+                job_data = client.get_job_status(job_id, include_logs=logs, logs_tail=logs_tail if logs else None)
                 
                 if format == 'json':
                     emit_json(job_data)
