@@ -5,6 +5,7 @@ Run command for executing individual tools
 import click
 import json
 import time
+import re
 from rich.console import Console
 from rich.table import Table
 
@@ -20,6 +21,7 @@ from ..utils.schema_loader import (
 )
 from ..client.api_client import IvyBloomAPIClient
 from ..utils.printing import emit_json
+import httpx
 
 console = get_console()
 
@@ -33,12 +35,15 @@ console = get_console()
 @click.option('--show-schema', is_flag=True, help='Show tool parameter schema and exit')
 @click.option('--output-format', default='table', type=click.Choice(['json', 'yaml', 'table']), help='Output format')
 @click.option('--json-verbose', is_flag=True, help='Print verbose JSON payload with resolved parameters and schema hints (implies --output-format json)')
+@click.option('--need', 'needs', multiple=True, help='Declare required features or outputs (name or name=value). Can be repeated.')
+@click.option('--want', 'wants', multiple=True, help='Declare optional features or outputs (name or name=value). Can be repeated.')
+@click.option('--feature', 'features', multiple=True, help='Set feature flags (name or name=value). Can be repeated.')
 @click.pass_context
-def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_schema, output_format, json_verbose):
-    """Run a tool with key=value parameters
+def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_schema, output_format, json_verbose, needs, wants, features):
+    """Run a tool with parameters and feature flags
 
-    - Usage: ivybloom run <tool> key=value [key=value ...]
-    - Params: pass tool inputs as key=value pairs (strings need quotes)
+    - Basic: ivybloom run <tool> key=value [key=value ...]
+    - Params: pass inputs as key=value (quote strings; JSON allowed for objects)
     - Schema: --show-schema to view accepted parameters and defaults
     - Validate: --dry-run to validate without executing
 
@@ -46,12 +51,17 @@ def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_s
       - ivybloom run esmfold protein_sequence=MKLLVLGLVGFGVGFG
       - ivybloom run diffdock protein_file="protein.pdb" ligand_smiles="CCO"
       - ivybloom run esmfold protein_sequence=MK... --project-id proj_123 --job-title "My Analysis" --wait
+      - ivybloom run diffdock protein_file=protein.pdb ligand_file=ligand.sdf --need primary=pdb --want scores --feature use_fast_mode=true
+      - ivybloom run reinvent input_json='{"scaffold":"c1ccccc1"}' --feature max_steps=2500 --want designs
 
     Common options:
       --project-id <id>   Project to associate this job with
       --job-title <text>  Custom job title
       --wait              Wait for completion, then print status
       --output-format     json|yaml|table (default: table)
+      --need NAME[=VAL]   Declare required outputs/capabilities (repeatable)
+      --want NAME[=VAL]   Declare optional outputs/capabilities (repeatable)
+      --feature NAME[=VAL]  Enable feature flags (repeatable)
 
     Tip: Run 'ivybloom tools info <tool>' to review parameters and examples.
     """
@@ -85,6 +95,17 @@ def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_s
             
             # Parse parameters
             tool_params = _parse_parameters(parameters)
+
+            # Normalize dashed keys to underscores for compatibility with schemas
+            tool_params = _normalize_param_keys(tool_params)
+
+            # Parse feature directives and embed under reserved key
+            feature_directives = _parse_feature_directives(needs, wants, features)
+            if feature_directives:
+                tool_params['__features__'] = feature_directives
+
+            # Tool-specific preprocessing (e.g., esmfold uniprot handling)
+            tool_params = _preprocess_tool_parameters(tool_name, tool_params, schema_data)
             
             # Validate parameters against schema
             validation_errors = _validate_parameters(tool_params, schema_data)
@@ -214,6 +235,146 @@ def _parse_parameters(parameter_strings):
     
     return params
 
+def _normalize_param_keys(value):
+    """Recursively normalize parameter keys by converting dashes to underscores.
+
+    The CLI should allow dashed input keys for ergonomics, but schemas typically
+    use snake_case. This normalizer converts keys like "ligand-file" -> "ligand_file".
+    """
+    if isinstance(value, dict):
+        normalized = {}
+        for k, v in value.items():
+            new_key = k.replace('-', '_') if isinstance(k, str) else k
+            normalized[new_key] = _normalize_param_keys(v)
+        return normalized
+    if isinstance(value, list):
+        return [_normalize_param_keys(v) for v in value]
+    return value
+
+def _parse_feature_directives(needs, wants, features):
+    """Parse --need/--want/--feature options into a structured directives object.
+
+    Each item can be "name" or "name=value". Values follow the same parsing rules
+    as regular parameters (JSON, numbers, booleans), and names are normalized to
+    snake_case by replacing dashes with underscores.
+    """
+    def parse_items(items):
+        result = {}
+        for raw in items or []:
+            if not isinstance(raw, str):
+                continue
+            if '=' in raw:
+                name, val = raw.split('=', 1)
+                name = (name or '').strip()
+                val = (val or '').strip()
+                # Attempt JSON/typed parse similar to _parse_parameters
+                if val.startswith('{') or val.startswith('[') or val.startswith('"'):
+                    try:
+                        parsed_val = json.loads(val)
+                    except json.JSONDecodeError:
+                        parsed_val = val
+                elif val.lower() in ('true', 'false'):
+                    parsed_val = (val.lower() == 'true')
+                elif val.isdigit():
+                    parsed_val = int(val)
+                else:
+                    try:
+                        parsed_val = float(val)
+                    except ValueError:
+                        parsed_val = val
+                result[name.replace('-', '_')] = parsed_val
+            else:
+                name = raw.strip().replace('-', '_')
+                if name:
+                    result[name] = True
+        return result
+
+    directives = {}
+    need_obj = parse_items(needs)
+    want_obj = parse_items(wants)
+    flag_obj = parse_items(features)
+    if need_obj:
+        directives['need'] = need_obj
+    if want_obj:
+        directives['want'] = want_obj
+    if flag_obj:
+        directives['flags'] = flag_obj
+    return directives
+
+def _looks_like_uniprot_accession(value: str) -> bool:
+    """Heuristic check for UniProt accession (e.g., P69905, Q9XYZ1)."""
+    if not isinstance(value, str):
+        return False
+    return bool(re.fullmatch(r"[OPQ][0-9][A-Z0-9]{3}[0-9]|[A-NR-Z][0-9]{5}", value))
+
+def _resolve_uniprot_sequence(accession: str) -> str:
+    """Fetch protein sequence from UniProt. Returns empty string on failure."""
+    try:
+        url = f"https://rest.uniprot.org/uniprotkb/{accession}.fasta"
+        resp = httpx.get(url, timeout=10)
+        if resp.status_code != 200:
+            return ""
+        text = resp.text or ""
+        lines = [ln.strip() for ln in text.splitlines() if ln.strip()]
+        # Remove FASTA header lines starting with '>'
+        seq_lines = [ln for ln in lines if not ln.startswith('>')]
+        seq = ''.join(seq_lines).strip()
+        # Basic validation: letters only
+        if seq and re.fullmatch(r"[ACDEFGHIKLMNPQRSTVWY]+", seq):
+            return seq
+        return ""
+    except Exception:
+        return ""
+
+def _preprocess_tool_parameters(tool_name: str, params: dict, schema_data: dict) -> dict:
+    """Apply tool-specific conveniences and normalize into schema-aligned params.
+
+    For 'esmfold':
+      - Accept 'uniprot', 'uniprot_id', 'uniprot_accession', 'accession' and resolve to
+        'protein_sequence' by fetching from UniProt
+      - Accept 'protein' and map based on content: sequence string -> 'protein_sequence'
+        URL ending with .fasta -> 'protein_fasta_url'
+    Unknown convenience keys are removed after mapping to avoid validation errors.
+    """
+    if not isinstance(params, dict):
+        return params
+
+    effective = dict(params)
+    tool_key = (tool_name or '').strip().lower()
+    if tool_key == 'esmfold':
+        # Gather convenience keys
+        uni_keys = ['uniprot', 'uniprot_id', 'uniprot_accession', 'accession']
+        uni_val = None
+        for k in uni_keys:
+            if k in effective and isinstance(effective[k], str) and effective[k].strip():
+                uni_val = effective[k].strip()
+                break
+        if uni_val and _looks_like_uniprot_accession(uni_val):
+            seq = _resolve_uniprot_sequence(uni_val)
+            if seq:
+                effective['protein_sequence'] = seq
+            else:
+                print_warning(f"Could not resolve UniProt accession '{uni_val}'. Proceeding without automatic sequence.")
+            # Remove convenience keys to avoid validation errors
+            for k in uni_keys:
+                effective.pop(k, None)
+
+        # 'protein' convenience mapping
+        if 'protein' in effective and 'protein_sequence' not in effective and 'protein_fasta_url' not in effective:
+            val = effective.get('protein')
+            if isinstance(val, str):
+                stripped = val.strip()
+                if re.fullmatch(r"[ACDEFGHIKLMNPQRSTVWY]+", stripped):
+                    effective['protein_sequence'] = stripped
+                    effective.pop('protein', None)
+                elif stripped.startswith('http') and stripped.lower().endswith(('.fasta', '.fa')):
+                    effective['protein_fasta_url'] = stripped
+                    effective.pop('protein', None)
+        # Final cleanup: remove any remaining unknown convenience keys
+        for k in uni_keys:
+            effective.pop(k, None)
+    return effective
+
 def _validate_parameters(params, schema_data):
     """Validate parameters against tool schema (recursive)."""
     errors = []
@@ -309,8 +470,10 @@ def _validate_parameters(params, schema_data):
         if required_field not in params:
             errors.append(f"Missing required parameter: {required_field}")
 
-    # Unknown at top-level
+    # Unknown at top-level (allow reserved __features__)
     for param_name in params.keys():
+        if param_name == '__features__':
+            continue
         if param_name not in properties:
             errors.append(f"Unknown parameter: {param_name}")
 
