@@ -24,12 +24,12 @@ console = get_console()
 
 @click.group()
 def tools():
-    """Discover tools and view parameter schemas
+    """Discover available tools and their parameters
 
     - List:    ivybloom tools list [--verbose]
     - Details: ivybloom tools info <tool>
     - Schema:  ivybloom tools schema <tool> [--format json]
-    - Completer hints: ivybloom tools completions <tool> [--format json]
+    - Hints:   ivybloom tools completions <tool> [--format json]
     """
     pass
 
@@ -162,10 +162,9 @@ def list_tools_cmd(ctx, format, verbose, format_json_with_schemas):
 @click.option('--format', default='table', type=click.Choice(['table', 'json']), help='Output format')
 @click.pass_context
 def info(ctx, tool_name, format):
-    """📋 Get detailed information about a specific tool
-    
-    Shows comprehensive parameter information for the specified tool.
-    Authentication is required to access tool schemas.
+    """Show detailed information and parameters for a tool
+
+    Displays required/optional parameters, types, defaults, and choices (enums).
     """
     config = ctx.obj['config']
     auth_manager = AuthManager(config)
@@ -194,8 +193,8 @@ def info(ctx, tool_name, format):
             return
             
         # Table format display
-        console.print(f"[bold cyan]🧬 {tool_name.title()}[/bold cyan]")
-        console.print(f"   {schema_data.get('description', 'No description available')}")
+        console.print(f"[bold cyan]{tool_name}[/bold cyan]")
+        console.print(f"{schema_data.get('description', 'No description available')}")
         console.print()
         
         # Extract schema parameters (normalized)
@@ -234,7 +233,28 @@ def info(ctx, tool_name, format):
                         console.print(f"      [dim]Default: {param_info['default']}[/dim]")
             
             console.print()
-            console.print(f"[bold]Summary:[/bold] {len(required_fields)} required, {len(optional_fields)} optional parameters")
+            console.print(f"[bold]Summary:[/bold] {len(required_fields)} required, {len(optional_fields)} optional")
+            console.print()
+            console.print("[bold]Common flags:[/bold] --need NAME[=VAL] (required outputs), --want NAME[=VAL] (optional outputs), --feature NAME[=VAL] (feature flags)")
+            console.print()
+            console.print("[bold]Example:[/bold]")
+            # Simple example with flags in comment for discoverability
+            example = []
+            for param_name in required_fields[:2]:
+                param_info = properties.get(param_name, {})
+                t = param_info.get('type', 'string')
+                if t == 'string':
+                    example.append(f'{param_name}="..."')
+                elif t == 'integer':
+                    example.append(f'{param_name}=1')
+                elif t == 'number':
+                    example.append(f'{param_name}=1.0')
+                elif t == 'boolean':
+                    example.append(f'{param_name}=true')
+                else:
+                    example.append(f'{param_name}=value')
+            example_str = ' '.join(example)
+            console.print(f"  ivybloom run {tool_name} {example_str}  # add --need/--want/--feature as needed")
         else:
             console.print("[yellow]No parameter information available[/yellow]")
             
@@ -249,11 +269,7 @@ def info(ctx, tool_name, format):
 @click.option('--format', default='table', type=click.Choice(['table', 'json']), help='Output format')
 @click.pass_context
 def schema(ctx, tool_name, format):
-    """📋 Get comprehensive parameter schema for a tool
-    
-    Display detailed parameter schema from the authenticated API.
-    Authentication is required to access tool schemas.
-    """
+    """Get comprehensive parameter schema for a tool"""
     config = ctx.obj['config']
     auth_manager = AuthManager(config)
     
@@ -279,8 +295,8 @@ def schema(ctx, tool_name, format):
         if format == 'json':
             emit_json(schema_data)
         else:
-            console.print(f"[bold cyan]📋 {tool_name.title()} Parameter Schema[/bold cyan]")
-            console.print(f"   {schema_data.get('description', 'No description available')}")
+            console.print(f"[bold cyan]{tool_name} schema[/bold cyan]")
+            console.print(f"{schema_data.get('description', 'No description available')}")
             console.print()
             
             # Show parameters with detailed information
