@@ -38,6 +38,7 @@ try:
     from .commands.batch import batch
     from .commands.data import data
     from .utils.auth import AuthManager
+    from .utils.test_gate import TestGate
 except ImportError:
     # Direct execution - use absolute imports
     import sys
@@ -124,6 +125,36 @@ def cli(ctx, config_file, api_url, debug, verbose, output_format, timeout, retri
     ctx.obj['offline'] = offline
     ctx.obj['profile'] = profile
 
+    # Always-on test gating for all CLI invocations (non-TUI as well).
+    # Run tests once before executing any subcommand other than the implicit root help/version.
+    try:
+        gate = TestGate()
+        result = gate.run_sync()
+        if not result.get('ok'):
+            from .utils.colors import print_error, print_warning
+            preview = (result.get('output') or '').strip()
+            max_chars = int(config.get('cli_test_preview_max_chars', 2000))
+            if len(preview) > max_chars:
+                preview = preview[-max_chars:]
+            header = result.get('summary_line') or 'Tests failed'
+            print_error(f"{header}. Fix issues and re-run.")
+            if preview:
+                console.print(f"[dim]{preview}[/dim]")
+            warnings = int(result.get('warnings') or 0)
+            if warnings > 0:
+                print_warning(f"Warnings: {warnings}")
+            raise SystemExit(2)
+        else:
+            warnings = int(result.get('warnings') or 0)
+            summary = result.get('summary_line') or 'All tests passed'
+            if warnings > 0:
+                console.print(f"[green]{summary}[/green]  [yellow](warnings: {warnings})[/yellow]")
+    except SystemExit:
+        raise
+    except Exception:
+        # If gating fails unexpectedly, don't block CLI usage
+        pass
+
     # Show welcome screen if no subcommand was invoked
     if ctx.invoked_subcommand is None:
         show_welcome_screen(__version__)
