@@ -8,14 +8,16 @@ import shutil
 import os
 
 from ..utils.config import Config
+from .debug_logger import DebugLogger
 
 
 class CLIRunner:
 	"""Thin wrapper around the installed ivybloom CLI for subprocess calls."""
 
-	def __init__(self, config: Config) -> None:
+	def __init__(self, config: Config, logger: DebugLogger | None = None) -> None:
 		self.config = config
 		self._session_env_overrides: Dict[str, str] = {}
+		self._logger = logger or DebugLogger(enabled=bool(getattr(config, "config", {}).get("debug", False)), prefix="CLI")
 
 	def run_cli_json(self, args: List[str], timeout: int = 30, env_overrides: Optional[Dict[str, str]] = None) -> Any:
 		cmd: List[str] = self._build_cmd(args)
@@ -24,8 +26,10 @@ class CLIRunner:
 			cmd += ["--format", "json"]
 		# Suppress colors/markup in JSON output and merge config-driven env
 		env = self._build_env(no_color=True, env_overrides=env_overrides)
+		self._logger.debug(f"run_cli_json: cmd={' '.join(cmd)}")
 		result = subprocess.run(cmd, capture_output=True, text=True, timeout=timeout, env=env)
 		if result.returncode != 0:
+			self._logger.error(f"run_cli_json: returncode={result.returncode} stderr={result.stderr.strip()}")
 			raise RuntimeError(result.stdout.strip() + "\n" + result.stderr.strip())
 		output = result.stdout.strip()
 		if not output:
@@ -53,15 +57,13 @@ class CLIRunner:
 		result = subprocess.run(cmd, input=input_text, capture_output=True, text=True, timeout=timeout, env=env)
 		if result.returncode != 0:
 			raise RuntimeError(result.stdout.strip() + "\n" + result.stderr.strip())
+		self._logger.debug(f"run_cli_text: cmd={' '.join(cmd)}")
 		return result.stdout
 
 	def _build_cmd(self, args: List[str]) -> List[str]:
-		# Prefer installed entrypoint if available in PATH, else fallback to in-process interpreter
-		base: List[str]
-		if shutil.which("ivybloom"):
-			base = ["ivybloom"]
-		else:
-			base = [sys.executable, "-m", "ivybloom_cli.main"]
+		# Always invoke the in-repo CLI module to ensure version consistency with the TUI
+		# This avoids PATH-installed older versions that may not share auth behavior.
+		base: List[str] = [sys.executable, "-m", "ivybloom_cli.main"]
 		cmd: List[str] = base[:]
 		# Include config file only if present to avoid passing 'None'
 		config_path = getattr(self.config, "config_path", None)
@@ -77,6 +79,7 @@ class CLIRunner:
 	def run_cli_stream(self, args: List[str], input_text: Optional[str] = None, env_overrides: Optional[Dict[str, str]] = None) -> Iterator[str]:
 		cmd: List[str] = self._build_cmd(args)
 		env = self._build_env(no_color=False, env_overrides=env_overrides)
+		self._logger.debug(f"run_cli_stream: cmd={' '.join(cmd)}")
 		proc = subprocess.Popen(cmd, stdin=subprocess.PIPE if input_text else None, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, text=True, env=env)
 		try:
 			if input_text and proc.stdin:
