@@ -98,6 +98,25 @@ class DetailsView:
 		else:
 			raise TypeError("DetailsView expects either 4 or 5 total arguments")
 
+	def _format_error(self, err: Any) -> str:
+		"""Return a readable error string for displaying in Static panels.
+
+		- Dict/list -> pretty JSON
+		- Exceptions whose first arg is dict/list -> pretty JSON
+		- Fallback to str(err)
+		"""
+		try:
+			if isinstance(err, (dict, list)):
+				return json.dumps(err, indent=2, ensure_ascii=False)
+			if isinstance(err, BaseException) and getattr(err, "args", None):
+				first = err.args[0]
+				if isinstance(first, (dict, list)):
+					return json.dumps(first, indent=2, ensure_ascii=False)
+			text = str(err)
+			return text
+		except Exception:
+			return str(err)
+
 	def render_summary(self, job: Dict[str, Any]) -> None:
 		"""Render summary.
 
@@ -233,6 +252,6 @@ class DetailsView:
 			table = self.artifacts_service.list_artifacts_table(job_id)
 			self.artifacts.update(table)
 		except Exception as e:
-			self.artifacts.update(f"[red]Artifacts list failed: {e}[/red]")
+			self.artifacts.update(f"[red]Artifacts list failed:[/red]\n{self._format_error(e)}")
 
 
